- `String and Bytes literals <https://docs.python.org/3/reference/lexical_analysis.html#string-and-bytes-literals>`_
- `Long form stackoverflow explanation  <https://stackoverflow.com/a/19030982/2519059>`_
